"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Redpanda Data, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import collections.abc
import grpc
import grpc.aio
from .... import redpanda
import typing
_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):
    ...

class BatchOutputServiceStub:
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None:
        ...
    Init: grpc.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitResponse]
    "Init is the first method called for a batch output and it passes the user's\n    configuration to the output.\n\n    The schema for the output configuration is specified in the `plugin.yaml`\n    file provided to Redpanda Connect.\n    "
    Connect: grpc.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectResponse]
    'Establish a connection to the downstream service. Connect will always be\n    called first when a writer is instantiated, and will be continuously\n    called with back off until a nil error is returned.\n\n    Once Connect returns a nil error the write method will be called until\n    either Error.NotConnected is returned, or the writer is closed.\n    '
    Send: grpc.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendResponse]
    'Write a batch of messages to a sink, or return an error if delivery is\n    not possible.\n\n    If this method returns Error.NotConnected then write will not be called\n    again until Connect has returned a nil error.\n    '
    Close: grpc.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseResponse]
    'Close the component, blocks until either the underlying resources are\n    cleaned up or the RPC deadline is reached.\n    '

class BatchOutputServiceAsyncStub:
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """
    Init: grpc.aio.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitResponse]
    "Init is the first method called for a batch output and it passes the user's\n    configuration to the output.\n\n    The schema for the output configuration is specified in the `plugin.yaml`\n    file provided to Redpanda Connect.\n    "
    Connect: grpc.aio.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectResponse]
    'Establish a connection to the downstream service. Connect will always be\n    called first when a writer is instantiated, and will be continuously\n    called with back off until a nil error is returned.\n\n    Once Connect returns a nil error the write method will be called until\n    either Error.NotConnected is returned, or the writer is closed.\n    '
    Send: grpc.aio.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendResponse]
    'Write a batch of messages to a sink, or return an error if delivery is\n    not possible.\n\n    If this method returns Error.NotConnected then write will not be called\n    again until Connect has returned a nil error.\n    '
    Close: grpc.aio.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseRequest, redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseResponse]
    'Close the component, blocks until either the underlying resources are\n    cleaned up or the RPC deadline is reached.\n    '

class BatchOutputServiceServicer(metaclass=abc.ABCMeta):
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """

    @abc.abstractmethod
    def Init(self, request: redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitRequest, context: _ServicerContext) -> typing.Union[redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitResponse, collections.abc.Awaitable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputInitResponse]]:
        """Init is the first method called for a batch output and it passes the user's
        configuration to the output.

        The schema for the output configuration is specified in the `plugin.yaml`
        file provided to Redpanda Connect.
        """

    @abc.abstractmethod
    def Connect(self, request: redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectRequest, context: _ServicerContext) -> typing.Union[redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectResponse, collections.abc.Awaitable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputConnectResponse]]:
        """Establish a connection to the downstream service. Connect will always be
        called first when a writer is instantiated, and will be continuously
        called with back off until a nil error is returned.

        Once Connect returns a nil error the write method will be called until
        either Error.NotConnected is returned, or the writer is closed.
        """

    @abc.abstractmethod
    def Send(self, request: redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendRequest, context: _ServicerContext) -> typing.Union[redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendResponse, collections.abc.Awaitable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputSendResponse]]:
        """Write a batch of messages to a sink, or return an error if delivery is
        not possible.

        If this method returns Error.NotConnected then write will not be called
        again until Connect has returned a nil error.
        """

    @abc.abstractmethod
    def Close(self, request: redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseRequest, context: _ServicerContext) -> typing.Union[redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseResponse, collections.abc.Awaitable[redpanda.runtime.v1alpha1.output_pb2.BatchOutputCloseResponse]]:
        """Close the component, blocks until either the underlying resources are
        cleaned up or the RPC deadline is reached.
        """

def add_BatchOutputServiceServicer_to_server(servicer: BatchOutputServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None:
    ...


# Copyright 2025 Redpanda Data, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import asyncio
import logging
from collections.abc import AsyncIterator
from typing import cast

from redpanda_connect import Message, Value, output, output_main

logger = logging.getLogger(__name__)


@output(max_in_flight=10)
async def logging_output(config: Value, messages: AsyncIterator[Message]):
    count = cast(dict[str, Value], config).get("repeat")
    async for msg in messages:
        for _ in range(cast(int, count)):
            logger.info(f"Received message: {msg}")
        await asyncio.sleep(0.1)


asyncio.run(output_main(logging_output))



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
Copyright 2025 Redpanda Data, Inc.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
"""
import abc
import collections.abc
import grpc
import grpc.aio
from .... import redpanda
import typing
_T = typing.TypeVar('_T')

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta):
    ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):
    ...

class AgentRuntimeStub:
    """`AgentRuntime` is the service that provides the ability to invoke an agent."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None:
        ...
    InvokeAgent: grpc.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentRequest, redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentResponse]

class AgentRuntimeAsyncStub:
    """`AgentRuntime` is the service that provides the ability to invoke an agent."""
    InvokeAgent: grpc.aio.UnaryUnaryMultiCallable[redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentRequest, redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentResponse]

class AgentRuntimeServicer(metaclass=abc.ABCMeta):
    """`AgentRuntime` is the service that provides the ability to invoke an agent."""

    @abc.abstractmethod
    def InvokeAgent(self, request: redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentRequest, context: _ServicerContext) -> typing.Union[redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentResponse, collections.abc.Awaitable[redpanda.runtime.v1alpha1.agent_pb2.InvokeAgentResponse]]:
        ...

def add_AgentRuntimeServicer_to_server(servicer: AgentRuntimeServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None:
    ...


"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(_runtime_version.Domain.PUBLIC, 5, 29, 0, '', 'redpanda/runtime/v1alpha1/message.proto')
_sym_db = _symbol_database.Default()
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'redpanda/runtime/v1alpha1/message.proto\x12\x19redpanda.runtime.v1alpha1\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1egoogle/protobuf/duration.proto"\xa2\x01\n\x0bStructValue\x12B\n\x06fields\x18\x01 \x03(\x0b22.redpanda.runtime.v1alpha1.StructValue.FieldsEntry\x1aO\n\x0bFieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b2 .redpanda.runtime.v1alpha1.Value:\x028\x01"=\n\tListValue\x120\n\x06values\x18\x01 \x03(\x0b2 .redpanda.runtime.v1alpha1.Value"\xf4\x02\n\x05Value\x12:\n\nnull_value\x18\x01 \x01(\x0e2$.redpanda.runtime.v1alpha1.NullValueH\x00\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x17\n\rinteger_value\x18\x03 \x01(\x03H\x00\x12\x16\n\x0cdouble_value\x18\x04 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x05 \x01(\x08H\x00\x125\n\x0ftimestamp_value\x18\x06 \x01(\x0b2\x1a.google.protobuf.TimestampH\x00\x12\x15\n\x0bbytes_value\x18\x07 \x01(\x0cH\x00\x12>\n\x0cstruct_value\x18\x08 \x01(\x0b2&.redpanda.runtime.v1alpha1.StructValueH\x00\x12:\n\nlist_value\x18\t \x01(\x0b2$.redpanda.runtime.v1alpha1.ListValueH\x00B\x06\n\x04kind"\xfb\x01\n\x05Error\x12\x0f\n\x07message\x18\x01 \x01(\t\x12,\n\x07backoff\x18\x02 \x01(\x0b2\x19.google.protobuf.DurationH\x00\x12F\n\rnot_connected\x18\x03 \x01(\x0b2-.redpanda.runtime.v1alpha1.Error.NotConnectedH\x00\x12C\n\x0cend_of_input\x18\x04 \x01(\x0b2+.redpanda.runtime.v1alpha1.Error.EndOfInputH\x00\x1a\x0e\n\x0cNotConnected\x1a\x0c\n\nEndOfInputB\x08\n\x06detail"\xc8\x01\n\x07Message\x12\x0f\n\x05bytes\x18\x01 \x01(\x0cH\x00\x126\n\nstructured\x18\x02 \x01(\x0b2 .redpanda.runtime.v1alpha1.ValueH\x00\x128\n\x08metadata\x18\x03 \x01(\x0b2&.redpanda.runtime.v1alpha1.StructValue\x12/\n\x05error\x18\x04 \x01(\x0b2 .redpanda.runtime.v1alpha1.ErrorB\t\n\x07payload"D\n\x0cMessageBatch\x124\n\x08messages\x18\x01 \x03(\x0b2".redpanda.runtime.v1alpha1.Message*\x1b\n\tNullValue\x12\x0e\n\nNULL_VALUE\x10\x00BBZ@github.com/redpanda-data/connect/v4/internal/rpcplugin/runtimepbb\x06proto3')
_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'redpanda.runtime.v1alpha1.message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
    _globals['DESCRIPTOR']._loaded_options = None
    _globals['DESCRIPTOR']._serialized_options = b'Z@github.com/redpanda-data/connect/v4/internal/rpcplugin/runtimepb'
    _globals['_STRUCTVALUE_FIELDSENTRY']._loaded_options = None
    _globals['_STRUCTVALUE_FIELDSENTRY']._serialized_options = b'8\x01'
    _globals['_NULLVALUE']._serialized_start = 1265
    _globals['_NULLVALUE']._serialized_end = 1292
    _globals['_STRUCTVALUE']._serialized_start = 136
    _globals['_STRUCTVALUE']._serialized_end = 298
    _globals['_STRUCTVALUE_FIELDSENTRY']._serialized_start = 219
    _globals['_STRUCTVALUE_FIELDSENTRY']._serialized_end = 298
    _globals['_LISTVALUE']._serialized_start = 300
    _globals['_LISTVALUE']._serialized_end = 361
    _globals['_VALUE']._serialized_start = 364
    _globals['_VALUE']._serialized_end = 736
    _globals['_ERROR']._serialized_start = 739
    _globals['_ERROR']._serialized_end = 990
    _globals['_ERROR_NOTCONNECTED']._serialized_start = 952
    _globals['_ERROR_NOTCONNECTED']._serialized_end = 966
    _globals['_ERROR_ENDOFINPUT']._serialized_start = 968
    _globals['_ERROR_ENDOFINPUT']._serialized_end = 980
    _globals['_MESSAGE']._serialized_start = 993
    _globals['_MESSAGE']._serialized_end = 1193
    _globals['_MESSAGEBATCH']._serialized_start = 1195
    _globals['_MESSAGEBATCH']._serialized_end = 1263


"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings
from ....redpanda.runtime.v1alpha1 import output_pb2 as redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2
GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False
try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True
if _version_not_supported:
    raise RuntimeError(f'The grpc package installed is at version {GRPC_VERSION},' + f' but the generated code in redpanda/runtime/v1alpha1/output_pb2_grpc.py depends on' + f' grpcio>={GRPC_GENERATED_VERSION}.' + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}' + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.')

class BatchOutputServiceStub(object):
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Init = channel.unary_unary('/redpanda.runtime.v1alpha1.BatchOutputService/Init', request_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitRequest.SerializeToString, response_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitResponse.FromString, _registered_method=True)
        self.Connect = channel.unary_unary('/redpanda.runtime.v1alpha1.BatchOutputService/Connect', request_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectRequest.SerializeToString, response_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectResponse.FromString, _registered_method=True)
        self.Send = channel.unary_unary('/redpanda.runtime.v1alpha1.BatchOutputService/Send', request_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendRequest.SerializeToString, response_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendResponse.FromString, _registered_method=True)
        self.Close = channel.unary_unary('/redpanda.runtime.v1alpha1.BatchOutputService/Close', request_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseRequest.SerializeToString, response_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseResponse.FromString, _registered_method=True)

class BatchOutputServiceServicer(object):
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """

    def Init(self, request, context):
        """Init is the first method called for a batch output and it passes the user's
        configuration to the output.

        The schema for the output configuration is specified in the `plugin.yaml`
        file provided to Redpanda Connect.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Connect(self, request, context):
        """Establish a connection to the downstream service. Connect will always be
        called first when a writer is instantiated, and will be continuously
        called with back off until a nil error is returned.

        Once Connect returns a nil error the write method will be called until
        either Error.NotConnected is returned, or the writer is closed.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Send(self, request, context):
        """Write a batch of messages to a sink, or return an error if delivery is
        not possible.

        If this method returns Error.NotConnected then write will not be called
        again until Connect has returned a nil error.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Close(self, request, context):
        """Close the component, blocks until either the underlying resources are
        cleaned up or the RPC deadline is reached.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

def add_BatchOutputServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {'Init': grpc.unary_unary_rpc_method_handler(servicer.Init, request_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitRequest.FromString, response_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitResponse.SerializeToString), 'Connect': grpc.unary_unary_rpc_method_handler(servicer.Connect, request_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectRequest.FromString, response_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectResponse.SerializeToString), 'Send': grpc.unary_unary_rpc_method_handler(servicer.Send, request_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendRequest.FromString, response_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendResponse.SerializeToString), 'Close': grpc.unary_unary_rpc_method_handler(servicer.Close, request_deserializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseRequest.FromString, response_serializer=redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseResponse.SerializeToString)}
    generic_handler = grpc.method_handlers_generic_handler('redpanda.runtime.v1alpha1.BatchOutputService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('redpanda.runtime.v1alpha1.BatchOutputService', rpc_method_handlers)

class BatchOutputService(object):
    """BatchOutput is an interface implemented by Benthos outputs that require
    Benthos to batch messages before dispatch in order to improve throughput.
    Each call to WriteBatch should block until either all messages in the batch
    have been successfully or unsuccessfully sent, or the RPC deadline is reached.

    Multiple write calls can be performed in parallel, and the constructor of an
    output must provide a MaxInFlight parameter indicating the maximum number of
    parallel batched write calls the output supports.
    """

    @staticmethod
    def Init(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redpanda.runtime.v1alpha1.BatchOutputService/Init', redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitRequest.SerializeToString, redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputInitResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def Connect(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redpanda.runtime.v1alpha1.BatchOutputService/Connect', redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectRequest.SerializeToString, redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputConnectResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def Send(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redpanda.runtime.v1alpha1.BatchOutputService/Send', redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendRequest.SerializeToString, redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputSendResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)

    @staticmethod
    def Close(request, target, options=(), channel_credentials=None, call_credentials=None, insecure=False, compression=None, wait_for_ready=None, timeout=None, metadata=None):
        return grpc.experimental.unary_unary(request, target, '/redpanda.runtime.v1alpha1.BatchOutputService/Close', redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseRequest.SerializeToString, redpanda_dot_runtime_dot_v1alpha1_dot_output__pb2.BatchOutputCloseResponse.FromString, options, channel_credentials, insecure, call_credentials, compression, wait_for_ready, timeout, metadata, _registered_method=True)